@@ -17,7 +17,6 @@ from __future__ import annotations
 import inspect
 from abc import ABC, abstractmethod
 from dataclasses import fields
-from datetime import datetime
 from typing import Type, get_type_hints, List, Union, Callable, Dict, Tuple
 
 import firefly.domain as ffd
@@ -25,11 +24,12 @@ import inflection
 # noinspection PyDataclass
 from jinjasql import JinjaSql
 
+from .abstract_storage_interface import AbstractStorageInterface
 from .rdb_repository import Index, Column
 
 
 # noinspection PyDataclass
-class RdbStorageInterface(ffd.LoggerAware, ABC):
+class RdbStorageInterface(AbstractStorageInterface, ABC):
     _serializer: ffd.Serializer = None
     _registry: ffd.Registry = None
     _j: JinjaSql = None
@@ -42,16 +42,6 @@ class RdbStorageInterface(ffd.LoggerAware, ABC):
     def __init__(self, **kwargs):
         self._tables_checked = []
 
-    def disconnect(self):
-        self._disconnect()
-
-    def _disconnect(self):
-        pass
-
-    def add(self, entity: Union[ffd.Entity, List[ffd.Entity]]):
-        self._check_prerequisites(entity.__class__)
-        self._add(entity)
-
     def _add(self, entity: Union[ffd.Entity, List[ffd.Entity]]):
         entities = entity
         if not isinstance(entity, list):
@@ -63,11 +53,6 @@ class RdbStorageInterface(ffd.LoggerAware, ABC):
             {'data': list(map(self._data_fields, entities))}
         ))
 
-    def all(self, entity_type: Type[ffd.Entity], criteria: ffd.BinaryOp = None, limit: int = None, offset: int = None,
-            sort: Tuple[Union[str, Tuple[str, bool]]] = None, raw: bool = False, count: bool = False):
-        self._check_prerequisites(entity_type)
-        return self._all(entity_type, criteria, limit, offset, raw=raw, count=count, sort=sort)
-
     def _generate_select(self, entity_type: Type[ffd.Entity], criteria: ffd.BinaryOp = None, limit: int = None,
                          offset: int = None, sort: Tuple[Union[str, Tuple[str, bool]]] = None, count: bool = False):
         indexes = [f.name for f in fields(entity_type)
@@ -111,10 +96,6 @@ class RdbStorageInterface(ffd.LoggerAware, ABC):
 
         return ret
 
-    def find(self, uuid: str, entity_type: Type[ffd.Entity]):
-        self._check_prerequisites(entity_type)
-        return self._find(uuid, entity_type)
-
     def _find(self, uuid: str, entity_type: Type[ffd.Entity]):
         results = self._execute(*self._generate_query(
             entity_type,
@@ -133,24 +114,6 @@ class RdbStorageInterface(ffd.LoggerAware, ABC):
 
         return self._build_entity(entity_type, results[0])
 
-    def remove(self, entity: Union[ffd.Entity, List[ffd.Entity], Callable], force: bool = False):
-        self._check_prerequisites(entity.__class__)
-        deletions = []
-
-        entities = entity
-        if not isinstance(entity, list):
-            entities = [entity]
-
-        for entity in entities:
-            if hasattr(entity, 'deleted_on') and not force:
-                entity.deleted_on = datetime.now()
-                self._update(entity)
-            else:
-                deletions.append(entity)
-
-        if len(deletions) > 0:
-            self._remove(deletions)
-
     def _remove(self, entity: Union[ffd.Entity, List[ffd.Entity], Callable]):
         criteria = entity
         if isinstance(entity, list):
@@ -162,12 +125,6 @@ class RdbStorageInterface(ffd.LoggerAware, ABC):
             'criteria': criteria
         }))
 
-    def update(self, entity: ffd.Entity):
-        self._check_prerequisites(entity.__class__)
-        if hasattr(entity, 'updated_on'):
-            entity.updated_on = datetime.now()
-        self._update(entity)
-
     def _update(self, entity: ffd.Entity):
         return self._execute(*self._generate_query(
             entity,
@@ -387,57 +344,3 @@ class RdbStorageInterface(ffd.LoggerAware, ABC):
         if self._map_all:
             return list(map(lambda c: c.name, self.get_entity_columns(entity)))
         return ['document']
-
-    def _get_relationships(self, entity: Type[ffd.Entity]):
-        relationships = {}
-        annotations_ = get_type_hints(entity)
-        for k, v in annotations_.items():
-            if k.startswith('_'):
-                continue
-            if isinstance(v, type) and issubclass(v, ffd.AggregateRoot):
-                relationships[k] = {
-                    'field_name': k,
-                    'target': v,
-                    'this_side': 'one',
-                }
-            elif ffd.is_type_hint(v):
-                origin = ffd.get_origin(v)
-                args = ffd.get_args(v)
-                if origin is List and issubclass(args[0], ffd.AggregateRoot):
-                    relationships[k] = {
-                        'field_name': k,
-                        'target': args[0],
-                        'this_side': 'many',
-                    }
-        return relationships
-
-    def _get_relationship(self, entity: Type[ffd.Entity], inverse_entity: Type[ffd.Entity]):
-        relationships = self._get_relationships(entity)
-        for k, v in relationships.items():
-            if v['target'] == inverse_entity:
-                return v
-
-    def _load_relationships(self, entity: Type[ffd.Entity], data: dict):
-        for k, v in self._get_relationships(entity).items():
-            if v['this_side'] == 'one':
-                data[k] = self._registry(v['target']).find(data[k])
-            elif v['this_side'] == 'many':
-                data[k] = list(self._registry(v['target']).filter(
-                    lambda ee: getattr(ee, v['target'].id_name()).is_in(data[k])
-                ))
-
-        return data
-
-    def _serialize_entity(self, entity: ffd.Entity):
-        relationships = self._get_relationships(entity.__class__)
-        if len(relationships.keys()) > 0:
-            obj = entity.to_dict(force_all=True, skip=list(relationships.keys()))
-            for k, v in relationships.items():
-                if v['this_side'] == 'one':
-                    obj[k] = getattr(entity, k).id_value()
-                elif v['this_side'] == 'many':
-                    obj[k] = list(map(lambda kk: kk.id_value(), getattr(entity, k)))
-        else:
-            obj = entity.to_dict(force_all=True)
-
-        return self._serializer.serialize(obj)
